Contributor's Guide
===================

In this section you will find information on how to contribute to Zun.
Content includes architectural overviews, tips and tricks for setting up
a development environment, and information on Cinder's lower level programming
APIs.


HowTos and Tutorials
--------------------

If you are new to Zun, this section contains information that should help
you quickly get started.

.. toctree::
  :maxdepth: 1

  Setting Up Your Development Environment <quickstart>

There are documents that should help you develop and contribute to the
project.

.. toctree::
  :maxdepth: 1

  Developer Contribution Guide <contributing>
  Setting Up Your Development Environment Under Mod WSGI <mod-wsgi>
  Running Tempest Tests <tempest-tests>
  Running Unit Tests <unit-tests>
  Multinode Devstack <multinode-devstack>

There are some other important documents also that helps new contributors to
contribute effectively towards code standards to the project.

.. toctree::
  :maxdepth: 1

  Adding a New API Method <api-microversion>
  Changing Zun DB Objects <objects>


Documentation Contribution
--------------------------
.. toctree::
   :maxdepth: 2

   documentation


Other Resources
---------------
.. toctree::
   :maxdepth: 3

   launchpad
   gerrit
   jenkins
   releasenotes
   capsule
   vision-reflection
